@@ -20,31 +20,37 @@
 // std
 #include <memory>
 
-// Mir
-#include <mir/shell/snapshot.h>
-
 //Qt
 #include <QtCore/QtCore>
 #include <QImage>
+#include <QSharedPointer>
 
 // Unity API
 #include <unity/shell/application/ApplicationInfoInterface.h>
 
 class QImage;
+namespace mir { namespace shell { class Session; }}
+
+namespace unitymir
+{
+
 class DesktopFileReader;
 class TaskController;
-namespace mir { namespace shell { class Session; }}
 
 class Application : public unity::shell::application::ApplicationInfoInterface {
     Q_OBJECT
     Q_PROPERTY(QString desktopFile READ desktopFile CONSTANT)
     Q_PROPERTY(QString exec READ exec CONSTANT)
     Q_PROPERTY(bool fullscreen READ fullscreen NOTIFY fullscreenChanged)
+    Q_PROPERTY(bool visible READ visible WRITE setVisible NOTIFY visibleChanged)
     Q_PROPERTY(Stage stage READ stage WRITE setStage NOTIFY stageChanged)
 
 public:
-    Application(const QString &appId, State state, const QStringList &arguments, QObject *parent = 0);
-    Application(DesktopFileReader *desktopFileReader, State state, const QStringList &arguments, QObject *parent = 0);
+    Application(const QSharedPointer<TaskController>& taskController,
+                DesktopFileReader *desktopFileReader,
+                State state,
+                const QStringList &arguments,
+                QObject *parent = 0);
     virtual ~Application();
 
     // ApplicationInfoInterface
@@ -55,14 +61,22 @@ public:
     Stage stage() const override;
     State state() const override;
     bool focused() const override;
+    QUrl screenshot() const override;
+
+    bool visible() const;
 
     void setStage(Stage stage);
+    void setVisible(const bool);
+
+    QImage screenshotImage() const;
+    void updateScreenshot();
 
     bool isValid() const;
     QString desktopFile() const;
     QString exec() const;
     bool fullscreen() const;
     std::shared_ptr<mir::shell::Session> session() const;
+    pid_t pid() const;
 
 public Q_SLOTS:
     void suspend();
@@ -72,9 +86,9 @@ public Q_SLOTS:
 Q_SIGNALS:
     void fullscreenChanged();
     void stageChanged(Stage stage);
+    void visibleChanged();
 
 private:
-    pid_t pid() const;
     void setPid(pid_t pid);
     void setState(State state);
     void setFocused(bool focus);
@@ -82,12 +96,16 @@ private:
     void setSession(const std::shared_ptr<mir::shell::Session>& session);
     void setSessionName(const QString& name);
 
+    QSharedPointer<TaskController> m_taskController;
     DesktopFileReader* m_desktopData;
     qint64 m_pid;
     Stage m_stage;
     State m_state;
     bool m_focused;
+    QUrl m_screenshot;
+    QImage m_screenshotImage;
     bool m_fullscreen;
+    bool m_visible; // duplicating internal Mir data :(
     std::shared_ptr<mir::shell::Session> m_session;
     QString m_sessionName;
     QStringList m_arguments;
@@ -98,6 +116,8 @@ private:
     friend class MirSurfaceManager;
 };
 
-Q_DECLARE_METATYPE(Application*)
+} // namespace unity-mir
+
+Q_DECLARE_METATYPE(unitymir::Application*)
 
 #endif  // APPLICATION_H
