@@ -17,11 +17,15 @@
 #ifndef APPLICATIONMANAGER_H
 #define APPLICATIONMANAGER_H
 
+// local
+#include "desktopfilereader.h"
+
 // std
 #include <memory>
 
 // Qt
 #include <QObject>
+#include <QSharedPointer>
 #include <QStringList>
 
 // Unity API
@@ -30,24 +34,37 @@
 // local
 #include "application.h"
 
-class ShellServerConfiguration;
-class DBusWindowStack;
-class MirSurfaceManager;
-class TaskController;
-
 namespace mir {
+    namespace geometry {
+        class Size;
+    }
     namespace shell {
         class Session;
         class Surface;
+        class FocusController;
     }
 }
 
+class ShellServerConfiguration;
+
+namespace unitymir
+{
+class DBusWindowStack;
+class MirSurfaceManager;
+class TaskController;
+class ProcInfo;
+
 class ApplicationManager : public unity::shell::application::ApplicationManagerInterface
 {
     Q_OBJECT
     Q_FLAGS(ExecFlags)
 
 public:
+    class Factory
+    {
+    public:
+        ApplicationManager* create();
+    };
     // Mapping enums to Ubuntu Platform API enums.
     enum Flag {
         NoFlag = 0x0,
@@ -57,32 +74,48 @@ public:
 
     static ApplicationManager* singleton();
 
-    explicit ApplicationManager(QObject *parent = 0);
+    explicit ApplicationManager(const QSharedPointer<TaskController>& taskController,
+                                const QSharedPointer<DesktopFileReader::Factory>& desktopFileReaderFactory,
+                                const QSharedPointer<ProcInfo>& processInfo,
+                                std::shared_ptr<mir::shell::FocusController> const& controller,
+                                QSize const& displaySize,
+                                QObject *parent = 0);
     virtual ~ApplicationManager();
 
     // ApplicationManagerInterface
     QString focusedApplicationId() const override;
-    Q_INVOKABLE Application* get(int index) const override;
-    Q_INVOKABLE Application* findApplication(const QString &appId) const override;
+    bool suspended() const;
+    void setSuspended(bool suspended);
+    Q_INVOKABLE unitymir::Application* get(int index) const override;
+    Q_INVOKABLE unitymir::Application* findApplication(const QString &appId) const override;
+    Q_INVOKABLE bool requestFocusApplication(const QString &appId) override;
     Q_INVOKABLE bool focusApplication(const QString &appId) override;
     Q_INVOKABLE void unfocusCurrentApplication() override;
-    Q_INVOKABLE Application* startApplication(const QString &appId, const QStringList &arguments) override;
+    Q_INVOKABLE unitymir::Application* startApplication(const QString &appId, const QStringList &arguments) override;
     Q_INVOKABLE bool stopApplication(const QString &appId) override;
+    Q_INVOKABLE bool updateScreenshot(const QString &appId);
 
     // QAbstractListModel
     int rowCount(const QModelIndex & parent = QModelIndex()) const override;
     QVariant data(const QModelIndex & index, int role = Qt::DisplayRole) const override;
 
-    Q_INVOKABLE Application *startApplication(const QString &appId, ExecFlags flags,
-                                              const QStringList &arguments = QStringList());
+    Q_INVOKABLE unitymir::Application *startApplication(const QString &appId, ExecFlags flags,
+                                                        const QStringList &arguments = QStringList());
     Q_INVOKABLE void move(int from, int to);
 
     const QList<Application*> &list() const { return m_applications; }
-    Application* findApplicationWithPid(const qint64 pid);
+    unitymir::Application* findApplicationWithPid(const qint64 pid);
+
+    // Internal helpers
+    void suspendApplication(Application *application);
+    void resumeApplication(Application *application);
+    int panelHeight();
+    QSize displaySize() const { return m_displaySize; }
 
 public Q_SLOTS:
     void authorizeSession(const quint64 pid, bool &authorized);
-
+    void placeSession(mir::shell::Session const*, uint32_t &x, uint32_t &y);
+    
     void onSessionStarting(std::shared_ptr<mir::shell::Session> const& session);
     void onSessionStopping(std::shared_ptr<mir::shell::Session> const& session);
     void onSessionFocused(std::shared_ptr<mir::shell::Session> const& session);
@@ -98,29 +131,46 @@ public Q_SLOTS:
 Q_SIGNALS:
     void focusRequested(const QString &appId);
 
+private Q_SLOTS:
+    void screenshotUpdated();
+
 private:
     void setFocused(Application *application);
     void add(Application *application);
     void remove(Application* application);
     Application* findApplicationWithSession(const std::shared_ptr<mir::shell::Session> &session);
     Application* findApplicationWithSession(const mir::shell::Session *session);
-    Application* findLastExecutedApplication();
+    Application* applicationForStage(Application::Stage stage);
     QModelIndex findIndex(Application* application);
+    bool checkFocusOnRemovedApplication(Application* application);
+    void shutdownApplication(Application* application);
+    void stopStartingApplication(const QString &appId);
 
     QList<Application*> m_applications;
     Application* m_focusedApplication; // remove as Mir has API for this
-    Application* m_applicationToBeFocused; // a basic form of focus stealing prevention
+    Application* m_mainStageApplication;
+    Application* m_sideStageApplication;
+    Application* m_msApplicationToBeFocused; // placeholder store for async focusing
+    Application* m_ssApplicationToBeFocused; // placeholder store for async focusing
     QStringList m_lifecycleExceptions;
-    ShellServerConfiguration* m_mirServer;
+    std::shared_ptr<mir::shell::FocusController> m_focusController;
     DBusWindowStack* m_dbusWindowStack;
-    QScopedPointer<TaskController> m_taskController;
-    static ApplicationManager* the_application_manager;
+    QSharedPointer<TaskController> m_taskController;
+    QSharedPointer<DesktopFileReader::Factory> m_desktopFileReaderFactory;
+    QSharedPointer<ProcInfo> m_procInfo;
+    int m_gridUnitPx;
     bool m_fenceNext;
+    QString m_nextFocusedAppId;
+    QSize m_displaySize;
+    int m_panelHeight;
+    bool m_suspended;
 
     friend class DBusWindowStack;
     friend class MirSurfaceManager;
 };
 
-Q_DECLARE_METATYPE(ApplicationManager*)
+} // namespace unitymir
+
+Q_DECLARE_METATYPE(unitymir::ApplicationManager*)
 
 #endif // APPLICATIONMANAGER_H
