@@ -19,18 +19,21 @@
 
 #include <QQuickImageProvider>
 
+namespace unitymir
+{
 class ApplicationManager;
+
 class ApplicationScreenshotProvider : public QQuickImageProvider
 {
 public:
     explicit ApplicationScreenshotProvider(ApplicationManager *appManager);
 
-    Flags flags() const override;
     QImage requestImage(const QString &appId, QSize *size, const QSize &requestedSize) override;
 
 private:
     ApplicationManager* m_appManager;
-    int m_panelHeight;
 };
 
+} // namespace unitymir
+
 #endif // APPLICATIONSCREENSHOTPROVIDER_H
