@@ -28,9 +28,11 @@
 // unity-mir
 #include "qmirserverapplication.h"
 #include "shellserverconfiguration.h"
-#include "surfacefactory.h"
 #include "logging.h"
 
+namespace unitymir
+{
+
 InputArea::InputArea(QQuickItem *parent)
     : QQuickItem(parent)
     , m_enabled(true)
@@ -187,3 +189,5 @@ void InputArea::setMirInputArea(const QRectF& relativeGeometry)
         m_surface->installInputArea(this);
     }
 }
+
+} // namespace unitymir
