@@ -25,13 +25,17 @@
 // mir
 #include <mircommon/mir/geometry/rectangle.h>
 
-class MirSurface;
 namespace mir { namespace shell { class Surface; }}
+
+namespace unitymir
+{
+class MirSurface;
+
 class InputArea : public QQuickItem
 {
     Q_OBJECT
     Q_PROPERTY(bool enabled READ enabled WRITE setEnabled NOTIFY enabledChanged)
-    Q_PROPERTY(MirSurface* surface READ surface WRITE setSurface NOTIFY surfaceChanged)
+    Q_PROPERTY(unitymir::MirSurface* surface READ surface WRITE setSurface NOTIFY surfaceChanged)
 
 public:
     explicit InputArea(QQuickItem *parent = 0);
@@ -70,4 +74,6 @@ private:
     friend class MirSurface;
 };
 
+} // namespace unitymir
+
 #endif // INPUTAREA_H
