@@ -27,6 +27,9 @@
 
 namespace mg = mir::geometry;
 
+namespace unitymir
+{
+
 MirSurface::MirSurface(std::shared_ptr<mir::shell::Surface> surface, Application* application, QQuickItem *parent)
     : QQuickItem(parent)
     , m_surface(surface)
@@ -101,7 +104,7 @@ void MirSurface::setWidth(qreal widthValue)
     Size size = m_surface->size();
     if (size.width.as_int() != (int) widthValue) {
         size.width = Width{widthValue};
-//        m_surface->set_size(size); //MISSING FROM API
+        m_surface->resize(size);
         Q_EMIT widthChanged();
     }
 }
@@ -113,7 +116,7 @@ void MirSurface::setHeight(qreal heightValue)
     Size size = m_surface->size();
     if (size.height.as_int() != (int) heightValue) {
         size.height = Height{heightValue};
-//        m_surface->set_size(size); //MISSING FROM API
+        m_surface->resize(size);
         Q_EMIT heightChanged();
     }
 }
@@ -223,3 +226,4 @@ void MirSurface::setAttribute(const MirSurfaceAttrib attribute, const int /*valu
     }
 }
 
+} // namespace unitymir
