@@ -27,14 +27,18 @@
 #include "shellserverconfiguration.h"
 #include "sessionlistener.h"
 #include "surfaceconfigurator.h"
-#include "surfacefactory.h"
 #include "focussetter.h"
 #include "logging.h"
 
 // mir
 #include <mir/shell/session.h>
+#include <mir/scene/surface.h>
 
 namespace msh = mir::shell;
+namespace ms = mir::scene;
+
+namespace unitymir
+{
 
 MirSurfaceManager *MirSurfaceManager::the_surface_manager = nullptr;
 
@@ -60,7 +64,7 @@ MirSurfaceManager::MirSurfaceManager(QObject *parent)
     }
     m_mirServer = mirServerApplication->server();
 
-    QObject::connect(m_mirServer->surfaceFactory(), &SurfaceFactory::shellSurfaceCreated,
+    QObject::connect(m_mirServer->sessionListener(), &SessionListener::shellSurfaceCreated,
                      this, &MirSurfaceManager::shellSurfaceCreated);
 
     QObject::connect(m_mirServer->sessionListener(), &SessionListener::sessionCreatedSurface,
@@ -138,7 +142,7 @@ void MirSurfaceManager::shellSurfaceCreated(const std::shared_ptr<msh::Surface>
     Q_EMIT shellSurfaceChanged(m_shellSurface);
 }
 
-void MirSurfaceManager::surfaceAttributeChanged(const msh::Surface *surface, const MirSurfaceAttrib attribute, const int value)
+void MirSurfaceManager::surfaceAttributeChanged(const ms::Surface *surface, const MirSurfaceAttrib attribute, const int value)
 {
     DLOG("MirSurfaceManager::surfaceAttributeChanged (this=%p, attrib=%d, value=%d)",
          this, static_cast<int>(attribute), value);
@@ -148,7 +152,18 @@ void MirSurfaceManager::surfaceAttributeChanged(const msh::Surface *surface, con
         it.value()->setAttribute(attribute, value);
         if (attribute == mir_surface_attrib_state &&
                 value == mir_surface_state_fullscreen) {
-            it.value()->application()->setFullscreen(static_cast<bool>(value));
+            // Only screen-wide applications are allowed to go fullscreen
+            if (it.value()->application()->stage() == Application::MainStage) {
+                it.value()->application()->setFullscreen(static_cast<bool>(value));
+                ApplicationManager* appMgr = static_cast<ApplicationManager*>(ApplicationManager::singleton());
+                QSize displaySize = appMgr->displaySize();
+                it.value()->setWidth(displaySize.width());
+                it.value()->setHeight(displaySize.height());
+                it.value()->setX(0);
+                it.value()->setY(0);
+            }
         }
     }
 }
+
+} // namespace unitymir
