@@ -29,8 +29,12 @@
 // local
 #include "mirsurface.h"
 
-class ShellServerConfiguration;
+namespace mir { namespace scene { class Surface; }}
 namespace mir { namespace shell { class Surface; class Session; }}
+class ShellServerConfiguration;
+
+namespace unitymir
+{
 
 class MirSurfaceManager : public QObject
 {
@@ -58,7 +62,7 @@ public Q_SLOTS:
     void sessionDestroyingSurface(mir::shell::Session const*, std::shared_ptr<mir::shell::Surface> const&);
     void shellSurfaceCreated(std::shared_ptr<mir::shell::Surface> const&);
 
-    void surfaceAttributeChanged(mir::shell::Surface const*, MirSurfaceAttrib, int);
+    void surfaceAttributeChanged(mir::scene::Surface const*, MirSurfaceAttrib, int);
 
 private:
     QHash<const mir::shell::Surface *, MirSurface *> m_surfaces;
@@ -67,4 +71,6 @@ private:
     static MirSurfaceManager *the_surface_manager;
 };
 
+} // namespace unitymir
+
 #endif // MIR_SURFACE_MANAGER_H
