@@ -36,14 +36,14 @@ static QObject* applicationManagerSingleton(QQmlEngine* engine, QJSEngine* scrip
     Q_UNUSED(scriptEngine);
     DLOG("applicationManagerSingleton (engine=%p, scriptEngine=%p)", engine, scriptEngine);
 
-    return ApplicationManager::singleton();
+    return unitymir::ApplicationManager::singleton();
 }
 
 static QObject* surfaceManagerSingleton(QQmlEngine* engine, QJSEngine* scriptEngine) {
     Q_UNUSED(engine);
     Q_UNUSED(scriptEngine);
     DLOG("surfaceManagerSingleton (engine=%p, scriptEngine=%p)", engine, scriptEngine);
-    return MirSurfaceManager::singleton();
+    return unitymir::MirSurfaceManager::singleton();
 }
 
 class UnityApplicationPlugin : public QQmlExtensionPlugin {
@@ -55,32 +55,34 @@ class UnityApplicationPlugin : public QQmlExtensionPlugin {
         DLOG("UnityApplicationPlugin::registerTypes (this=%p, uri='%s')", this, uri);
         ASSERT(QLatin1String(uri) == QLatin1String("Unity.Application"));
 
-        qRegisterMetaType<ApplicationManager*>("ApplicationManager*"); //need for queueing signals
+        qRegisterMetaType<unitymir::ApplicationManager*>("ApplicationManager*"); //need for queueing signals
 
         qmlRegisterUncreatableType<unity::shell::application::ApplicationManagerInterface>(
                     uri, 0, 1, "ApplicationManagerInterface", "Abstract interface. Cannot be created in QML");
-        qmlRegisterSingletonType<ApplicationManager>(
+        qmlRegisterSingletonType<unitymir::ApplicationManager>(
                     uri, 0, 1, "ApplicationManager", applicationManagerSingleton);
         qmlRegisterUncreatableType<unity::shell::application::ApplicationInfoInterface>(
                     uri, 0, 1, "ApplicationInfoInterface", "Abstract interface. Cannot be created in QML");
-        qmlRegisterUncreatableType<Application>(
+        qmlRegisterUncreatableType<unitymir::Application>(
                     uri, 0, 1, "ApplicationInfo", "ApplicationInfo can't be instantiated");
-        qmlRegisterSingletonType<MirSurfaceManager>(
+        qmlRegisterSingletonType<unitymir::MirSurfaceManager>(
                     uri, 0, 1, "SurfaceManager", surfaceManagerSingleton);
-        qmlRegisterUncreatableType<MirSurface>(
+        qmlRegisterUncreatableType<unitymir::MirSurface>(
                     uri, 0, 1, "MirSurface", "MirSurface can't be instantiated");
-        qmlRegisterType<InputArea>(uri, 0, 1, "InputArea");
-        qmlRegisterType<ShellInputArea>(uri, 0, 1, "ShellInputArea");
-        qmlRegisterType<InputFilterArea>(uri, 0, 1, "InputFilterArea");
-        qmlRegisterType<UbuntuKeyboardInfo>(uri, 0, 1, "UbuntuKeyboardInfo");
+        qmlRegisterType<unitymir::InputArea>(uri, 0, 1, "InputArea");
+        qmlRegisterType<unitymir::ShellInputArea>(uri, 0, 1, "ShellInputArea");
+        qmlRegisterType<unitymir::InputFilterArea>(uri, 0, 1, "InputFilterArea");
+        qmlRegisterType<unitymir::UbuntuKeyboardInfo>(uri, 0, 1, "UbuntuKeyboardInfo");
     }
 
     virtual void initializeEngine(QQmlEngine *engine, const char *uri)
     {
         QQmlExtensionPlugin::initializeEngine(engine, uri);
 
-        ApplicationManager* appManager = static_cast<ApplicationManager*>(applicationManagerSingleton(engine, NULL));
-        engine->addImageProvider(QLatin1String("screenshot"), new ApplicationScreenshotProvider(appManager));
+        unitymir::ApplicationManager* appManager =
+                static_cast<unitymir::ApplicationManager*>(applicationManagerSingleton(engine, NULL));
+        engine->addImageProvider(QLatin1String("application"),
+                                 new unitymir::ApplicationScreenshotProvider(appManager));
     }
 };
 
