@@ -23,6 +23,9 @@
 // Qt
 #include <QDebug>
 
+namespace unitymir
+{
+
 ShellInputArea::ShellInputArea(QQuickItem *parent) : InputArea(parent)
 {
     auto surface = MirSurfaceManager::singleton()->shellSurface();
@@ -43,3 +46,5 @@ void ShellInputArea::setShellSurface(MirSurface *surface)
 {
     doSetSurface(surface);
 }
+
+} // namespace unitymir
