@@ -19,6 +19,8 @@
 
 #include "inputarea.h"
 
+namespace unitymir
+{
 class MirSurface;
 
 class ShellInputArea : public InputArea
@@ -34,4 +36,6 @@ private Q_SLOT:
     void setShellSurface(MirSurface *surface);
 };
 
+} // namespace unitymir
+
 #endif // SHELLINPUTAREA_H
