@@ -22,17 +22,20 @@
 #include <QObject>
 
 #include "application.h"
+#include "applicationcontroller.h"
+#include "processcontroller.h"
 
-// upstart
-extern "C" {
-    #include "upstart-app-launch.h"
-}
+namespace unitymir
+{
 
 class TaskController : public QObject
 {
     Q_OBJECT
 public:
-    static TaskController* singleton();
+    TaskController(
+            QObject* parent,
+            const QSharedPointer<ApplicationController>& app_controller,
+            const QSharedPointer<ProcessController>& processController = QSharedPointer<ProcessController>(new ProcessController()));
     ~TaskController();
 
     bool start(const QString& appId, const QStringList& args);
@@ -49,12 +52,20 @@ Q_SIGNALS:
     void requestFocus(const QString& appId);
     void requestResume(const QString& appId);
 
-private:
-    TaskController(QObject *parent = 0);
+private Q_SLOTS:
+    void onApplicationAboutToBeStarted(const QString& id);
+    void onApplicationStarted(const QString& id);
+    void onApplicationStopped(const QString& id);
+    void onApplicationFocusRequest(const QString& id);
+    void onApplicationResumeRequest(const QString& id);
 
-    static TaskController* m_theTaskController;
-    upstart_app_launch_app_observer_t preStartCallback, startedCallback, stopCallback, focusCallback, resumeCallback;
-    upstart_app_launch_app_failed_observer_t failureCallback;
+    void onApplicationError(const QString& id, ApplicationController::Error error);
+
+private:
+    QSharedPointer<ApplicationController> m_appController;
+    QSharedPointer<ProcessController> m_processController;
 };
 
+} // namespace unitymir
+
 #endif // TASKCONTROLLER_H
