@@ -24,6 +24,9 @@ namespace {
     const char gServerName[] = "ubuntu-keyboard-info";
 }
 
+namespace unitymir
+{
+
 UbuntuKeyboardInfo::UbuntuKeyboardInfo(QObject *parent)
     : QObject(parent),
     m_consecutiveAttempts(0),
@@ -151,3 +154,5 @@ void UbuntuKeyboardInfo::buildSocketFilePath()
     }
 
 }
+
+} // namespace unitymir
