@@ -20,6 +20,9 @@
 #include <QLocalSocket>
 #include <QTimer>
 
+namespace unitymir
+{
+
 // Temporary solution to get information about the onscreen keyboard
 // This shouldn't be needed once the OSK is a properly sized surface
 // instead of a fullscreen one.
@@ -75,4 +78,6 @@ private:
     QString m_socketFilePath;
 };
 
+} // namespace unitymir
+
 #endif // UBUNTU_KEYBOARD_INFO_H
