@@ -21,17 +21,31 @@
 
 #include "mirserver/mir/shell/placement_strategy.h"
 #include "mirserver/mir/shell/display_layout.h"
+#include "mir/shell/session.h"
+#include "mir/scene/depth_id.h"
 
-class InitialSurfacePlacementStrategy : public mir::shell::PlacementStrategy
+#include <QObject>
+#include <QMutex>
+
+class InitialSurfacePlacementStrategy : public QObject, public mir::shell::PlacementStrategy
 {
+    Q_OBJECT
+
 public:
-    InitialSurfacePlacementStrategy(std::shared_ptr<mir::shell::DisplayLayout> const& displayLayout);
+    InitialSurfacePlacementStrategy(const std::shared_ptr<mir::shell::DisplayLayout> &displayLayout,
+                                    QObject *parent = 0);
+    ~InitialSurfacePlacementStrategy();
 
-    mir::shell::SurfaceCreationParameters place(mir::shell::Session const& session,
-                                                mir::shell::SurfaceCreationParameters const& requestParameters) override;
+    mir::shell::SurfaceCreationParameters place(const mir::shell::Session &session,
+                                                const mir::shell::SurfaceCreationParameters &requestParameters) override;
 
+Q_SIGNALS:
+    void requestPlacementForSession(const mir::shell::Session *session, uint32_t &x, uint32_t &y);
+        
 private:
-    std::shared_ptr<mir::shell::DisplayLayout> const m_displayLayout;
+    const std::shared_ptr<mir::shell::DisplayLayout> m_displayLayout;
+    QMutex m_mutex;
+    bool m_mainShellSurfaceFound;
 };
 
 #endif // INITIALSURFACEPLACEMENTSTRATEGY_H
