@@ -39,4 +39,14 @@ private:
     Q_DISABLE_COPY(QMirServer)
 };
 
+
+// class factory
+extern "C" {
+    QMirServer *createQMirServer(int argc, const char **argv);
+
+    int runQMirServerWithClient(QMirServer *mirServer, std::function<int(int, const char**, ShellServerConfiguration*)> client);
+
+    void destroyQMirServer(QMirServer *mirServer);
+}
+
 #endif // QMIRSERVER_H
