@@ -16,15 +16,34 @@
 
 #include "qmirserverapplication.h"
 
+class QMirServerApplicationPrivate {
+public:
+    QMirServerApplicationPrivate(ShellServerConfiguration* serverConfiguration, QMirServerApplication *qq)
+        : q_ptr(qq)
+        , serverConfiguration(serverConfiguration)
+    {}
+
+    QMirServerApplication * const q_ptr;
+    ShellServerConfiguration *serverConfiguration;
+    Q_DECLARE_PUBLIC(QMirServerApplication)
+};
+
+
 QMirServerApplication::QMirServerApplication(int &argc, char **argv, ShellServerConfiguration* serverConfiguration)
     : QGuiApplication(argc, argv)
-    , m_serverConfiguration(serverConfiguration)
+    , d_ptr(new QMirServerApplicationPrivate(serverConfiguration, this))
 {
 }
 
+QMirServerApplication::~QMirServerApplication()
+{
+    delete d_ptr;
+}
+
 ShellServerConfiguration* QMirServerApplication::server() const
 {
-    return m_serverConfiguration;
+    Q_D(const QMirServerApplication);
+    return d->serverConfiguration;
 }
 
 // class factory implemenation
@@ -41,4 +60,3 @@ extern "C" {
         delete mirServer;
     }
 }
-
