@@ -20,6 +20,7 @@
 #include <QGuiApplication>
 
 class ShellServerConfiguration;
+class QMirServerApplicationPrivate;
 
 class QMirServerApplication : public QGuiApplication
 {
@@ -27,11 +28,15 @@ class QMirServerApplication : public QGuiApplication
 
 public:
     explicit QMirServerApplication(int &argc, char **argv, ShellServerConfiguration* serverConfiguration);
+    ~QMirServerApplication();
 
     ShellServerConfiguration* server() const;
 
+protected:
+    QMirServerApplicationPrivate * const d_ptr;
+
 private:
-    ShellServerConfiguration* m_serverConfiguration;
+    Q_DECLARE_PRIVATE(QMirServerApplication)
 };
 
 
