@@ -17,6 +17,8 @@
 #include "sessionlistener.h"
 #include "logging.h"
 
+#include <mir/shell/session.h>
+
 namespace msh = mir::shell;
 
 Q_DECLARE_METATYPE(std::shared_ptr<msh::Session>)
@@ -27,6 +29,7 @@ SessionListener::SessionListener(QObject *parent) :
     DLOG("SessionListener::SessionListener (this=%p)", this);
     // need to register type to send over threads with signal/slot
     qRegisterMetaType<std::shared_ptr<msh::Session>>("std::shared_ptr<mir::shell::Session>");
+    qRegisterMetaType<std::shared_ptr<msh::Surface>>("std::shared_ptr<mir::shell::Surface>");
 }
 
 SessionListener::~SessionListener()
@@ -63,7 +66,13 @@ void SessionListener::unfocused()
 void SessionListener::surface_created(msh::Session& session, std::shared_ptr<msh::Surface> const& surface)
 {
     DLOG("SessionListener::surface_created (this=%p, session=%p, surface=%p)", this, &session, (void*)surface.get());
-    Q_EMIT sessionCreatedSurface(&session, surface);
+    static bool mainShellSurfaceFound = false;
+    if (session.process_id() == 0 && !mainShellSurfaceFound) {
+        Q_EMIT shellSurfaceCreated(surface);
+        mainShellSurfaceFound = true;
+    } else {
+        Q_EMIT sessionCreatedSurface(&session, surface);
+    }
 }
 
 void SessionListener::destroying_surface(msh::Session& session, std::shared_ptr<mir::shell::Surface> const& surface)
