@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013 Canonical, Ltd.
+ * Copyright (C) 2013-2014 Canonical, Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License version 3, as published by
@@ -16,20 +16,25 @@
 
 #include "shellserverconfiguration.h"
 
+#include "displayconfigurationpolicy.h"
+#include "unityprotobufservice.h"
 #include "initialsurfaceplacementstrategy.h"
 #include "serverstatuslistener.h"
+#include "sessioncreator.h"
 #include "sessionlistener.h"
 #include "surfaceconfigurator.h"
-#include "surfacefactory.h"
 #include "sessionauthorizer.h"
 #include "focussetter.h"
 #include "logging.h"
 
+namespace mg = mir::graphics;
 namespace msh = mir::shell;
+namespace ms = mir::scene;
 
 ShellServerConfiguration::ShellServerConfiguration(int argc, char const* argv[], QObject* parent)
     : QObject(parent)
     , DefaultServerConfiguration(argc, argv)
+    , m_unityService(std::make_shared<UnityProtobufService>())
 {
     DLOG("ShellServerConfiguration created");
 }
@@ -38,6 +43,17 @@ ShellServerConfiguration::~ShellServerConfiguration()
 {
 }
 
+std::shared_ptr<mg::DisplayConfigurationPolicy>
+ShellServerConfiguration::the_display_configuration_policy()
+{
+    return display_configuration_policy(
+        [this]
+        {
+            bool alpha = (qgetenv("XDG_SESSION_CLASS") == "greeter");
+            return std::make_shared<DisplayConfigurationPolicy>(DefaultServerConfiguration::the_display_configuration_policy(), alpha);
+        });
+}
+
 std::shared_ptr<msh::PlacementStrategy>
 ShellServerConfiguration::the_shell_placement_strategy()
 {
@@ -58,10 +74,10 @@ ShellServerConfiguration::the_shell_session_listener()
         });
 }
 
-std::shared_ptr<msh::SurfaceConfigurator>
-ShellServerConfiguration::the_shell_surface_configurator()
+std::shared_ptr<ms::SurfaceConfigurator>
+ShellServerConfiguration::the_surface_configurator()
 {
-    return shell_surface_configurator(
+    return surface_configurator(
         [this]()
         {
             return std::make_shared<SurfaceConfigurator>();
@@ -78,17 +94,17 @@ ShellServerConfiguration::the_session_authorizer()
     });
 }
 
-// FIXME: Needed to detect the shell's surface - there must be a better way
-std::shared_ptr<msh::SurfaceFactory>
-ShellServerConfiguration::the_shell_surface_factory()
+std::shared_ptr<mir::frontend::SessionCreator>
+ShellServerConfiguration::the_session_creator()
 {
-    if (!m_surfaceFactory)
-    {
-        m_surfaceFactory = std::make_shared<SurfaceFactory>(
-            DefaultServerConfiguration::the_shell_surface_factory());
-    }
-
-    return m_surfaceFactory;
+    return session_creator([this]
+        {
+            return std::make_shared<SessionCreator>(
+                m_unityService,
+                the_ipc_factory(the_frontend_shell(), the_buffer_allocator()),
+                the_session_authorizer(),
+                the_message_processor_report());
+        });
 }
 
 std::shared_ptr<msh::FocusSetter>
@@ -125,6 +141,14 @@ ShellServerConfiguration::the_server_status_listener()
 // scope the unique pointer will be destroyed so we return 0
 //
 
+InitialSurfacePlacementStrategy *ShellServerConfiguration::placementStrategy()
+{
+    auto sharedPtr = the_shell_placement_strategy();
+    if (sharedPtr.unique()) return 0;
+
+    return static_cast<InitialSurfacePlacementStrategy*>(sharedPtr.get());
+}
+
 SessionAuthorizer *ShellServerConfiguration::sessionAuthorizer()
 {
     auto sharedPtr = the_session_authorizer();
@@ -143,17 +167,12 @@ SessionListener *ShellServerConfiguration::sessionListener()
 
 SurfaceConfigurator *ShellServerConfiguration::surfaceConfigurator()
 {
-    auto sharedPtr = the_shell_surface_configurator();
+    auto sharedPtr = the_surface_configurator();
     if (sharedPtr.unique()) return 0;
 
     return static_cast<SurfaceConfigurator*>(sharedPtr.get());
 }
 
-SurfaceFactory *ShellServerConfiguration::surfaceFactory()
-{
-    return m_surfaceFactory.get();
-}
-
 FocusSetter *ShellServerConfiguration::focusSetter()
 {
     auto sharedPtr = the_shell_focus_setter();
