@@ -16,19 +16,19 @@
 
 #include "surfaceconfigurator.h"
 
-namespace msh = mir::shell;
+namespace ms = mir::scene;
 
 SurfaceConfigurator::SurfaceConfigurator()
 {
     qRegisterMetaType<MirSurfaceAttrib>("MirSurfaceAttrib");
 }
 
-int SurfaceConfigurator::select_attribute_value(msh::Surface const&, MirSurfaceAttrib, int requested_value)
+int SurfaceConfigurator::select_attribute_value(ms::Surface const&, MirSurfaceAttrib, int requested_value)
 {
     return requested_value;
 }
 
-void SurfaceConfigurator::attribute_set(msh::Surface const& surface, MirSurfaceAttrib attrib, int value)
+void SurfaceConfigurator::attribute_set(ms::Surface const& surface, MirSurfaceAttrib attrib, int value)
 {
     Q_EMIT surfaceAttributeChanged(&surface, attrib, value);
 }
